@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# (c) 2021 Zombie
 
 import wx
 import os
@@ -203,7 +204,8 @@ class ThumbDemoConfig(wx.Frame):
         dlg = wx.MessageDialog(self, self.about, self.name + " Demo",
                                wx.OK | wx.ICON_INFORMATION)
 
-        dlg.SetFont(wx.Font(8, wx.NORMAL, wx.NORMAL, wx.NORMAL, False))
+        dlg.SetFont(wx.Font(8, wx.FONTFAMILY_DEFAULT, wx.NORMAL, wx.NORMAL,
+                            False))
         dlg.ShowModal()
         dlg.Destroy()
 
